/* Response box styling */
.response-box {
    background: #1a1a1a;
    border: 1px solid #444;
    border-radius: 4px;
    padding: 15px;
    margin-top: 15px;
    max-height: 600px;
    overflow-y: auto;
    font-family: 'Courier New', monospace;
    font-size: 13px;
    white-space: pre-wrap;
    position: relative;
}

.response-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-bottom: 10px;
    padding-bottom: 10px;
    border-bottom: 1px solid #444;
}

.response-title {
    color: #4CAF50;
    font-weight: bold;
}

.response-actions {
    display: flex;
    gap: 10px;
}

.btn-copy {
    background: #2196F3;
    color: white;
    padding: 6px 12px;
    border: none;
    border-radius: 4px;
    cursor: pointer;
    font-size: 12px;
}

.btn-copy:hover {
    background: #1976D2;
}

.btn-copy.copied {
    background: #4CAF50;
}

.response-content {
    color: #e0e0e0;
}

/* JSON syntax highlighting */
.json-key {
    color: #4CAF50;
}

.json-string {
    color: #FFA726;
}

.json-number {
    color: #42A5F5;
}

.json-boolean {
    color: #AB47BC;
}

.json-null {
    color: #78909C;
}

/* Loading state */
.loading {
    display: flex;
    align-items: center;
    gap: 10px;
    color: #4CAF50;
}

.loading::before {
    content: "";
    display: inline-block;
    width: 16px;
    height: 16px;
    border: 2px solid #4CAF50;
    border-top-color: transparent;
    border-radius: 50%;
    animation: spin 1s linear infinite;
}

@keyframes spin {
    to { transform: rotate(360deg); }
}

/* Error state */
.error {
    color: #f44336;
    background: rgba(244, 67, 54, 0.1);
    padding: 10px;
    border-radius: 4px;
    border-left: 3px solid #f44336;
}

/* Placeholder */
.response-placeholder {
    color: #666;
    font-style: italic;
}



.json-editor {
    width: 100%;
    min-height: 200px;
    padding: 10px;
    background: #0d1117;
    border: 2px solid #444 !important;
    border-radius: 4px;
    color: #c9d1d9;
    font-family: 'Consolas', 'Monaco', 'Courier New', monospace;
    font-size: 14px;
    line-height: 1.5;
    overflow: auto;
    white-space: pre;
    display: block;
    box-sizing: border-box;
}

.json-editor:focus {
    border-color: #58a6ff !important;
    outline: none;
}


.tool-name-highlight {
    color: #2196F3 !important;  /* Blue instead of green */
    font-weight: bold !important;
    font-size: 1.2em !important;  /* Slightly larger */
}