/* Overall layout structure */
* { margin: 0; padding: 0; box-sizing: border-box; }

body {
    font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
    background: #1a1a1a;
    color: #e0e0e0;
    padding: 20px;
}

.container {
    max-width: 1400px;
    margin: 0 auto;
}

/* Header */
.header {
    background: #2d2d2d;
    padding: 20px;
    border-radius: 8px;
    margin-bottom: 20px;
}

.header h1 {
    color: #4CAF50;
    margin-bottom: 10px;
    font-size: 1.8em;
}

.header .subtitle {
    color: #888;
    margin-bottom: 10px;
}

.header-links {
    margin-top: 10px;
}

.link {
    color: #4CAF50;
    text-decoration: none;
    margin-right: 15px;
}

.link:hover {
    text-decoration: underline;
}

.status {
    display: inline-block;
    padding: 4px 12px;
    border-radius: 12px;
    font-size: 12px;
    font-weight: bold;
    margin-left: 10px;
}

.status.connected { background: #4CAF50; color: white; }
.status.disconnected { background: #f44336; color: white; }

/* Cards */
.card {
    background: #2d2d2d;
    padding: 20px;
    border-radius: 8px;
    margin-bottom: 20px;
}

.card h2 {
    color: #4CAF50;
    margin-bottom: 15px;
    font-size: 1.3em;
}

/* Info lines */
.info-line {
    color: #aaa;
    font-size: 13px;
    margin-top: 5px;
    font-family: 'Courier New', monospace;
}

.info-line strong {
    color: #4CAF50;
}

/* Category tabs */
.category-tabs {
    display: flex;
    gap: 10px;
    margin-bottom: 20px;
    border-bottom: 2px solid #444;
    padding-bottom: 0;
}

.category-tab {
    background: #1a1a1a;
    color: #aaa;
    padding: 12px 24px;
    border: none;
    border-top-left-radius: 8px;
    border-top-right-radius: 8px;
    cursor: pointer;
    font-size: 15px;
    font-weight: 500;
    transition: all 0.3s;
    border-bottom: 3px solid transparent;
}

.category-tab:hover {
    background: #2d2d2d;
    color: #e0e0e0;
}

.category-tab.active {
    background: #2d2d2d;
    color: #4CAF50;
    border-bottom-color: #4CAF50;
}

/* Tool selector area */
.tool-selector-area {
    margin-bottom: 20px;
}

/* Dynamic form area */
.dynamic-form-area {
    min-height: 200px;
}

#toolForm {
    display: flex;
    flex-direction: column;
    gap: 15px;
}
